
# Show time

Handles show predicates which are generated during preprocessing for `#show` directives.

<!-- ::: src/metasp/encodings/show.lp
    handler: asp
    options:
        glossary:
            include_references: false
        predicate_table: true
        encodings:
            git_link: true
        start_level: 1 -->
